@@ -21,9 +21,9 @@ class Country(ModelSQL, ModelView):
         super(Country, cls).__setup__()
         cls._sql_constraints += [
             ('name_uniq', 'UNIQUE(name)',
-                'The name of the country must be unique!'),
+                'The name of the country must be unique.'),
             ('code_uniq', 'UNIQUE(code)',
-                'The code of the country must be unique!'),
+                'The code of the country must be unique.'),
             ]
         cls._order.insert(0, ('name', 'ASC'))
 
@@ -34,11 +34,12 @@ class Country(ModelSQL, ModelView):
         return [(cls._rec_name,) + clause[1:]]
 
     @classmethod
-    def create(cls, vals):
-        if 'code' in vals and vals['code']:
-            vals = vals.copy()
-            vals['code'] = vals['code'].upper()
-        return super(Country, cls).create(vals)
+    def create(cls, vlist):
+        vlist = [x.copy() for x in vlist]
+        for vals in vlist:
+            if 'code' in vals and vals['code']:
+                vals['code'] = vals['code'].upper()
+        return super(Country, cls).create(vlist)
 
     @classmethod
     def write(cls, countries, vals):
@@ -58,13 +59,16 @@ class Subdivision(ModelSQL, ModelView):
     type = fields.Selection([
         ('administration', 'Administration'),
         ('administrative area', 'Administrative area'),
+        ('administrative atoll', 'Administrative atoll'),
         ('administrative region', 'Administrative Region'),
         ('administrative territory', 'Administrative Territory'),
         ('area', 'Area'),
         ('atoll', 'Atoll'),
+        ('arctic region', 'Arctic Region'),
         ('autonomous city', 'Autonomous City'),
         ('autonomous commune', 'Autonomous Commune'),
         ('autonomous communities', 'Autonomous communities'),
+        ('autonomous community', 'Autonomous community'),
         ('autonomous district', 'Autonomous District'),
         ('autonomous island', 'Autonomous island'),
         ('autonomous monastic state', 'Autonomous monastic state'),
@@ -74,21 +78,27 @@ class Subdivision(ModelSQL, ModelView):
         ('autonomous republic', 'Autonomous republic'),
         ('autonomous sector', 'Autonomous sector'),
         ('autonomous territory', 'Autonomous territory'),
+        ('autonomous territorial unit', 'Autonomous territorial unit'),
         ('borough', 'Borough'),
         ('canton', 'Canton'),
         ('capital city', 'Capital city'),
         ('capital district', 'Capital District'),
         ('capital metropolitan city', 'Capital Metropolitan City'),
         ('capital territory', 'Capital Territory'),
+        ('chains (of islands)', 'Chains (of islands)'),
         ('city', 'City'),
         ('city corporation', 'City corporation'),
         ('city with county rights', 'City with county rights'),
         ('commune', 'Commune'),
+        ('constitutional province', 'Constitutional province'),
+        ('council area', 'Council area'),
         ('country', 'Country'),
         ('county', 'County'),
         ('department', 'Department'),
         ('dependency', 'Dependency'),
+        ('development region', 'Development region'),
         ('district', 'District'),
+        ('district council area', 'District council area'),
         ('division', 'Division'),
         ('economic prefecture', 'Economic Prefecture'),
         ('economic region', 'Economic region'),
@@ -97,10 +107,13 @@ class Subdivision(ModelSQL, ModelView):
         ('federal dependency', 'Federal Dependency'),
         ('federal district', 'Federal District'),
         ('federal territories', 'Federal Territories'),
+        ('geographical entity', 'Geographical entity'),
         ('geographical region', 'Geographical region'),
         ('geographical unit', 'Geographical unit'),
         ('governorate', 'Governorate'),
         ('included for completeness', 'Included for completeness'),
+        ('indigenous region', 'Indigenous region'),
+        ('island', 'Island'),
         ('island council', 'Island council'),
         ('island group', 'Island group'),
         ('local council', 'Local council'),
@@ -117,16 +130,21 @@ class Subdivision(ModelSQL, ModelView):
         ('overseas territorial collectivity',
             'Overseas territorial collectivity'),
         ('parish', 'Parish'),
+        ('popularates', 'Popularates'),
         ('prefecture', 'Prefecture'),
         ('principality', 'Principality'),
         ('province', 'Province'),
+        ('quarter', 'Quarter'),
         ('rayon', 'Rayon'),
         ('region', 'Region'),
         ('regional council', 'Regional council'),
         ('republic', 'Republic'),
+        ('republican city', 'Republican City'),
+        ('self-governed part', 'Self-governed part'),
         ('special administrative region', 'Special administrative region'),
         ('special city', 'Special city'),
         ('special district', 'Special District'),
+        ('special island authority', 'Special island authority'),
         ('special municipality', 'Special Municipality'),
         ('special region', 'Special Region'),
         ('special zone', 'Special zone'),
@@ -137,6 +155,9 @@ class Subdivision(ModelSQL, ModelView):
         ('two-tier county', 'Two-tier county'),
         ('union territory', 'Union territory'),
         ('unitary authority', 'Unitary authority'),
+        ('unitary authority (england)', 'Unitary authority (england)'),
+        ('unitary authority (wales)', 'Unitary authority (wales)'),
+        ('zone', 'zone'),
         ], 'Type', required=True)
     parent = fields.Many2One('country.subdivision', 'Parent')
 
@@ -152,10 +173,12 @@ class Subdivision(ModelSQL, ModelView):
         return [(cls._rec_name,) + clause[1:]]
 
     @classmethod
-    def create(cls, vals):
-        if 'code' in vals and vals['code']:
-            vals['code'] = vals['code'].upper()
-        return super(Subdivision, cls).create(vals)
+    def create(cls, vlist):
+        vlist = [x.copy() for x in vlist]
+        for vals in vlist:
+            if 'code' in vals and vals['code']:
+                vals['code'] = vals['code'].upper()
+        return super(Subdivision, cls).create(vlist)
 
     @classmethod
     def write(cls, subdivisions, vals):
